NAME

Spreadsheet::Reader::ExcelXML::Chartsheet - An ExcelXML chartsheet placeholder

SYNOPSIS

See the SYNOPSIS in Spreadsheet::Reader::ExcelXML

DESCRIPTION

This documentation is written to explain ways to use this module when writing your own excel parser or extending this package. To use the general package for excel parsing out of the box please review the documentation for Workbooks , Worksheets , and Cells.

This class is a placeholder for chartsheet parsing. Where there is a 'chartsheet' style tab in the workbook this class is used to receive that data so the workbook won't fail automatically. Chartsheet files are not chart sub elements they are just tabs in a workbook similar to 'worksheets' that only hold one chart. The ability to parse 'chartsheet's is still pending. There are attributes and some methods in the class but none will be documented untill there is a clear path for them to provide functionality.

SUPPORT

github Spreadsheet::Reader::ExcelXML/issues

TODO

1. Provide access to chartsheet content

AUTHOR

Jed Lund
jandrew@cpan.org

COPYRIGHT

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the LICENSE file included with this module.

This software is copyrighted (c) 2016 by Jed Lund

DEPENDENCIES

Spreadsheet::Reader::ExcelXML - the package

SEE ALSO

Spreadsheet::Read - generic Spreadsheet reader

Spreadsheet::ParseExcel - Excel binary version 2003 and earlier (.xls files)

Spreadsheet::XLSX - Excel version 2007 and later

Spreadsheet::ParseXLSX - Excel version 2007 and later

Log::Shiras

All lines in this package that use Log::Shiras are commented out